@@ -8,9 +8,7 @@
 """ Unit test for ‘daemon’ module. """
 
 import collections
-import contextlib
 import errno
-import functools
 import importlib
 import io
 import os
@@ -337,6 +335,13 @@ class DaemonContext_is_open_TestCase(DaemonContext_BaseTestCase):
                 setattr, instance, 'is_open', object())
 
 
+def make_fake_streams(testcase):
+    """ Make fake system stream files for `testcase`. """
+    testcase.fake_streams = {
+            name: FakeFileDescriptorStringIO()
+            for name in ['stdin', 'stdout', 'stderr']}
+
+
 class DaemonContext_open_TestCase(DaemonContext_BaseTestCase):
     """ Test cases for DaemonContext.open method. """
 
@@ -809,14 +814,6 @@ class DaemonContext_make_signal_handler_TestCase(DaemonContext_BaseTestCase):
         result = instance._make_signal_handler(target)
         self.assertEqual(expected_result, result)
 
-    def test_returns_method_for_str_name(self):
-        """ Should return DaemonContext method for name of type ‘str’. """
-        instance = self.test_instance
-        target = str('terminate')
-        expected_result = instance.terminate
-        result = instance._make_signal_handler(target)
-        self.assertEqual(expected_result, result)
-
     def test_raises_error_for_unknown_name(self):
         """ Should raise AttributeError for unknown method name. """
         instance = self.test_instance
@@ -1265,11 +1262,7 @@ class get_stream_file_descriptors_TestCase(scaffold.TestCase):
         super().setUp()
 
         self.patch_get_maximum_file_descriptors()
-        self.fake_streams = dict(
-                stdin=FakeFileDescriptorStringIO(),
-                stdout=FakeFileDescriptorStringIO(),
-                stderr=FakeFileDescriptorStringIO(),
-                )
+        make_fake_streams(self)
 
     def patch_get_maximum_file_descriptors(self):
         """ Patch the function `get_maximum_file_descriptors`. """
@@ -1470,60 +1463,20 @@ def make_total_file_descriptor_range_patch(testcase, fake_maxfd):
         """
     attr_patcher = unittest.mock.patch.object(
             daemon.daemon, "_total_file_descriptor_range",
-            new=(0, fake_maxfd))
+            new=range(0, fake_maxfd))
     return attr_patcher
 
 
-def make_total_file_descriptor_set_patch(testcase, fake_maxfd):
-    """ Make a `_total_file_descriptor_set` patch for the `testcase`.
+def patch_total_file_descriptor_range(testcase, fake_maxfd):
+    """ Patch `_total_file_descriptor_range` for the `testcase`.
 
         :param testcase: The `unittest.TestCase` instance to patch.
         :param fake_maxfd: The fake maximum file descriptor value.
-        :return: The `unittest.mock.patch` object.
+        :return: ``None``.
         """
-    attr_patcher = unittest.mock.patch.object(
-            daemon.daemon, "_total_file_descriptor_set",
-            new=set(range(0, fake_maxfd)))
-    return attr_patcher
-
-
-class _get_candidate_file_descriptors_TestCase(scaffold.TestCaseWithScenarios):
-    """ Test cases for function `_get_candidate_file_descriptors`. """
-
-    scenarios = [
-            ('exclude-three', {
-                'fake_maxfd': 10,
-                'test_kwargs': {
-                    'exclude': {3, 5, 8},
-                    },
-                'expected_result': {0, 1, 2, 4, 6, 7, 9},
-                }),
-            ('exclude-one', {
-                'fake_maxfd': 5,
-                'test_kwargs': {
-                    'exclude': {4},
-                    },
-                'expected_result': {0, 1, 2, 3},
-                }),
-            ('exclude-none', {
-                'fake_maxfd': 5,
-                'test_kwargs': {
-                    'exclude': set(),
-                },
-                'expected_result': {0, 1, 2, 3, 4},
-                }),
-            ]
-
-    def test_returns_expected_file_descriptors(self):
-        """ Should return the expected set of file descriptors. """
-        with contextlib.ExitStack() as patch_stack:
-            patch_stack.enter_context(
-                make_total_file_descriptor_range_patch(self, self.fake_maxfd))
-            patch_stack.enter_context(
-                make_total_file_descriptor_set_patch(self, self.fake_maxfd))
-            result = daemon.daemon._get_candidate_file_descriptors(
-                    **self.test_kwargs)
-        self.assertEqual(result, self.expected_result)
+    attr_patcher = make_total_file_descriptor_range_patch(testcase, fake_maxfd)
+    attr_patcher.start()
+    testcase.addCleanup(attr_patcher.stop)
 
 
 class _get_candidate_file_descriptor_ranges_TestCase(
@@ -1613,19 +1566,75 @@ class _get_candidate_file_descriptor_ranges_TestCase(
                     (0, 5),
                     ],
                 }),
+            ('exclude-within-large-candidate-range', {
+                'fake_maxfd': 0x3FFFFF0,
+                'test_kwargs': {
+                    'exclude': {0x1000000},
+                    },
+                'expected_result': [
+                    (0, 0x1000000),
+                    (0x1000001, 0x3FFFFF0),
+                    ],
+                }),
             ]
 
+    def setUp(self):
+        """ Set up test fixtures. """
+        super().setUp()
+
+        patch_total_file_descriptor_range(self, fake_maxfd=self.fake_maxfd)
+
     def test_returns_expected_file_descriptors(self):
         """ Should return the expected set of file descriptors. """
-        with contextlib.ExitStack() as patch_stack:
-            patch_stack.enter_context(
-                make_total_file_descriptor_range_patch(self, self.fake_maxfd))
-            patch_stack.enter_context(
-                make_total_file_descriptor_set_patch(self, self.fake_maxfd))
-            result = daemon.daemon._get_candidate_file_descriptor_ranges(
-                    **self.test_kwargs)
+        result = daemon.daemon._get_candidate_file_descriptor_ranges(
+                **self.test_kwargs)
         self.assertEqual(result, self.expected_result)
 
+
+class _get_candidate_file_descriptor_ranges_ErrorTestCase(
+        scaffold.TestCaseWithScenarios):
+    """
+    Error test cases for function `_get_candidate_file_descriptor_ranges`.
+    """
+
+    scenarios = [
+            ('exclude-set-includes-string', {
+                'fake_maxfd': 5,
+                'test_kwargs': {
+                    'exclude': {4, "b0gUs", 7},
+                },
+                'expected_error_type': TypeError,
+                }),
+            ('exclude-set-includes-float', {
+                'fake_maxfd': 5,
+                'test_kwargs': {
+                    'exclude': {4, 5.2, 7},
+                },
+                'expected_error_type': TypeError,
+                }),
+            ('exclude-set-includes-float-nan', {
+                'fake_maxfd': 5,
+                'test_kwargs': {
+                    'exclude': {4, float('nan'), 7},
+                },
+                'expected_error_type': TypeError,
+                }),
+            ('exclude-set-includes-none', {
+                'fake_maxfd': 5,
+                'test_kwargs': {
+                    'exclude': {4, None, 7},
+                },
+                'expected_error_type': TypeError,
+                }),
+            ]
+
+    def test_raises_expected_error(self):
+        """ Should raise the expected error type for the condition. """
+        self.assertRaises(
+            self.expected_error_type,
+            daemon.daemon._get_candidate_file_descriptor_ranges,
+            **self.test_kwargs)
+
 
 @unittest.mock.patch.object(os, "closerange")
 class _close_file_descriptor_ranges_TestCase(scaffold.TestCaseWithScenarios):
@@ -1675,17 +1684,7 @@ class close_all_open_files_TestCase(scaffold.TestCase):
         """ Set up test fixtures. """
         super().setUp()
 
-        total_file_descriptor_range_patch = (
-                make_total_file_descriptor_range_patch(
-                    self, fake_maxfd=self.fake_maxfd))
-        total_file_descriptor_range_patch.start()
-        self.addCleanup(total_file_descriptor_range_patch.stop)
-        total_file_descriptor_set_patch = (
-                make_total_file_descriptor_set_patch(
-                    self, fake_maxfd=self.fake_maxfd))
-        total_file_descriptor_set_patch.start()
-        self.addCleanup(total_file_descriptor_set_patch.stop)
-
+        patch_total_file_descriptor_range(self, fake_maxfd=self.fake_maxfd)
         self.patch_os_closerange()
 
     def patch_os_closerange(self):
@@ -2220,8 +2219,8 @@ class make_default_signal_map_TestCase(scaffold.TestCase):
             default map should not contain any signals which are not
             defined in the `signal` module.
             """
-        del(self.default_signal_map[self.fake_signal_module.SIGTTOU])
-        del(self.fake_signal_module.SIGTTOU)
+        del self.default_signal_map[self.fake_signal_module.SIGTTOU]
+        del self.fake_signal_module.SIGTTOU
         expected_result = self.default_signal_map
         result = daemon.daemon.make_default_signal_map()
         self.assertEqual(expected_result, result)
@@ -2263,7 +2262,7 @@ class register_atexit_function_TestCase(scaffold.TestCase):
         mock_func_atexit_register.assert_called_with(func)
 
 
-# Copyright © 2008–2022 Ben Finney <ben+python@benfinney.id.au>
+# Copyright © 2008–2023 Ben Finney <ben+python@benfinney.id.au>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the GNU General Public License as published by the
